@@ -118,7 +118,7 @@ int main(int argc, char *argv[])
                      QStringLiteral(KASTS_VERSION_STRING),
                      i18n("Podcast Player"),
                      KAboutLicense::GPL,
-                     i18n("© 2020–2023 KDE Community"));
+                     i18n("© 2020–2024 KDE Community"));
     about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("tobias.fella@kde.org"), QStringLiteral("https://tobiasfella.de"));
     about.addAuthor(i18n("Bart De Vries"), QString(), QStringLiteral("bart@mogwai.be"));
     about.setProgramLogo(QVariant(QIcon(QStringLiteral(":/logo.svg"))));
@@ -160,7 +160,7 @@ int main(int argc, char *argv[])
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "Sync", &Sync::instance());
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "SystrayIcon", &SystrayIcon::instance());
     qmlRegisterSingletonInstance<ColorSchemer>("org.kde.kasts", 1, 0, "ColorSchemer", &ColorSchemer::instance());
-    if (SettingsManager::self()->colorScheme().isEmpty()) {
+    if (!SettingsManager::self()->colorScheme().isEmpty()) {
         ColorSchemer::instance().apply(SettingsManager::self()->colorScheme());
     }
 
